import 'package:flutter/material.dart';
import 'package:fl_chart/fl_chart.dart';

import '../../../config/app_colors.dart';
import '../../../models/discoveries.dart';
import '../../../utils/color_extensions.dart';
import '../../../ui/widgets/charts/custom_bar_chart.dart';

class ChartDiscoveriesTracks extends CustomBarChart {
  final DiscoveriesData chartData;

  ChartDiscoveriesTracks({super.key, required this.chartData});

  @override
  Widget build(BuildContext context) {
    return Container(
      height: this.chartHeight,
      child: LayoutBuilder(builder: (context, constraints) {
        return getBarChart(
          barWidth: this.getBarWidth(constraints.maxWidth, this.chartData.data.keys.length),
          backgroundColor: Theme.of(context).colorScheme.onSurface,
        );
      }),
    );
  }

  double getMaxCountsValue() {
    double maxValue = 0;

    this.chartData.data.keys.forEach((key) {
      DiscoveriesDataValue? value = this.chartData.data[key];
      if (value != null) {
        double newTracksCount = value.newTracksCount.toDouble();

        if (newTracksCount > maxValue) {
          maxValue = newTracksCount;
        }
      }
    });

    return maxValue;
  }

  List<BarChartGroupData> getDataCounts(double barWidth) {
    List<BarChartGroupData> data = [];

    final newTracksBarColor = AppColors.contentColorBlue.darken(20);

    this.chartData.data.keys.forEach((key) {
      DiscoveriesDataValue? value = this.chartData.data[key];
      if (value != null) {
        final int date = DateTime.parse(key).millisecondsSinceEpoch;

        data.add(this.getBarItem(
          x: date,
          values: [
            value.newTracksCount.toDouble(),
          ],
          barColors: [
            newTracksBarColor,
          ],
          barWidth: barWidth,
        ));
      }
    });

    return data;
  }
}
